==> haskell-libyaml-0.1.1.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-Llb1OZTx989JsbEfdcqo5y
key: libyaml-0.1.1.0-Llb1OZTx989JsbEfdcqo5y
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: a12bf4e755355d2181ad24da6f34061a
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-Llb1OZTx989JsbEfdcqo5y
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-BJf0jROjhGpHw40KA5fH20
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.1.0-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-23ElDnZqhv41xKSmS9s3cT
key: libyaml-0.1.1.0-23ElDnZqhv41xKSmS9s3cT
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: 576ec2c1be640d86a773d70a047f7925
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-23ElDnZqhv41xKSmS9s3cT
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7GVNmVxDZaILlce8KGbrl1
    resourcet-1.2.2-GrOWSwxHGOj1LZp32tMtSY
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
